public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula
@ 2011-08-11 12:44 Jarkko Nikula
  2011-08-11 13:09 ` Mark Brown
  2011-08-12  2:48 ` Mark Brown
  0 siblings, 2 replies; 4+ messages in thread
From: Jarkko Nikula @ 2011-08-11 12:44 UTC (permalink / raw)
  To: alsa-devel; +Cc: linux-kernel, Mark Brown, Liam Girdwood, Jarkko Nikula

My gmail account got disabled and I'm not going to reopen it.

Signed-off-by: Jarkko Nikula <jarkko.nikula@bitmer.com>
---
Be careful about your age in google+ registration...
---
 MAINTAINERS                 |    2 +-
 include/sound/tlv320aic3x.h |    2 +-
 sound/soc/omap/n810.c       |    4 ++--
 sound/soc/omap/omap-mcbsp.c |    4 ++--
 sound/soc/omap/omap-mcbsp.h |    2 +-
 sound/soc/omap/omap-pcm.c   |    4 ++--
 sound/soc/omap/omap-pcm.h   |    2 +-
 sound/soc/omap/rx51.c       |    2 +-
 8 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/MAINTAINERS b/MAINTAINERS
index 1f8267f..3e6b34c 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -4604,7 +4604,7 @@ F:	arch/arm/mach-omap2/clockdomain2xxx_3xxx.c
 F:	arch/arm/mach-omap2/clockdomain44xx.c
 
 OMAP AUDIO SUPPORT
-M:	Jarkko Nikula <jhnikula@gmail.com>
+M:	Jarkko Nikula <jarkko.nikula@bitmer.com>
 L:	alsa-devel@alsa-project.org (subscribers-only)
 L:	linux-omap@vger.kernel.org
 S:	Maintained
diff --git a/include/sound/tlv320aic3x.h b/include/sound/tlv320aic3x.h
index 99e0308..ffd9bc7 100644
--- a/include/sound/tlv320aic3x.h
+++ b/include/sound/tlv320aic3x.h
@@ -1,7 +1,7 @@
 /*
  * Platform data for Texas Instruments TLV320AIC3x codec
  *
- * Author: Jarkko Nikula <jhnikula@gmail.com>
+ * Author: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
diff --git a/sound/soc/omap/omap-mcbsp.h b/sound/soc/omap/omap-mcbsp.h
index 9a7dedd..65cde9d 100644
--- a/sound/soc/omap/omap-mcbsp.h
+++ b/sound/soc/omap/omap-mcbsp.h
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2008 Nokia Corporation
  *
- * Contact: Jarkko Nikula <jhnikula@gmail.com>
+ * Contact: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
  * This program is free software; you can redistribute it and/or
diff --git a/sound/soc/omap/omap-pcm.h b/sound/soc/omap/omap-pcm.h
index a0ed1db..f95fe30 100644
--- a/sound/soc/omap/omap-pcm.h
+++ b/sound/soc/omap/omap-pcm.h
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2008 Nokia Corporation
  *
- * Contact: Jarkko Nikula <jhnikula@gmail.com>
+ * Contact: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
  * This program is free software; you can redistribute it and/or
diff --git a/sound/soc/omap/rx51.c b/sound/soc/omap/rx51.c
index 0aae998..893300a 100644
--- a/sound/soc/omap/rx51.c
+++ b/sound/soc/omap/rx51.c
@@ -5,7 +5,7 @@
  *
  * Contact: Peter Ujfalusi <peter.ujfalusi@ti.com>
  *          Eduardo Valentin <eduardo.valentin@nokia.com>
- *          Jarkko Nikula <jhnikula@gmail.com>
+ *          Jarkko Nikula <jarkko.nikula@bitmer.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
diff --git a/sound/soc/omap/n810.c b/sound/soc/omap/n810.c
index 83d213b..62e292f 100644
--- a/sound/soc/omap/n810.c
+++ b/sound/soc/omap/n810.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2008 Nokia Corporation
  *
  * Contact: Jarkko Nikula <jhnikula@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -402,6 +402,6 @@ static void __exit n810_soc_exit(void)
 module_init(n810_soc_init);
 module_exit(n810_soc_exit);
 
-MODULE_AUTHOR("Jarkko Nikula <jhnikula@gmail.com>");
+MODULE_AUTHOR("Jarkko Nikula <jarkko.nikula@bitmer.com>");
 MODULE_DESCRIPTION("ALSA SoC Nokia N810");
 MODULE_LICENSE("GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2008 Nokia Corporation
  *
- * Contact: Jarkko Nikula <jhnikula@gmail.com>
+ * Contact: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *
  * This program is free software; you can redistribute it and/or
diff --git a/sound/soc/omap/omap-mcbsp.c b/sound/soc/omap/omap-mcbsp.c
index 07b7723..ebcc2d4 100644
--- a/sound/soc/omap/omap-mcbsp.c
+++ b/sound/soc/omap/omap-mcbsp.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2008 Nokia Corporation
  *
  * Contact: Jarkko Nikula <jhnikula@gmail.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -780,6 +780,6 @@ static void __exit snd_omap_mcbsp_exit(void)
 }
 module_exit(snd_omap_mcbsp_exit);
 
-MODULE_AUTHOR("Jarkko Nikula <jhnikula@gmail.com>");
+MODULE_AUTHOR("Jarkko Nikula <jarkko.nikula@bitmer.com>");
 MODULE_DESCRIPTION("OMAP I2S SoC Interface");
 MODULE_LICENSE("GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2008 Nokia Corporation
  *
- * Contact: Jarkko Nikula <jhnikula@gmail.com>
+ * Contact: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
diff --git a/sound/soc/omap/omap-pcm.c b/sound/soc/omap/omap-pcm.c
index b2f5751..9b5c88a 100644
--- a/sound/soc/omap/omap-pcm.c
+++ b/sound/soc/omap/omap-pcm.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2008 Nokia Corporation
  *
  * Contact: Jarkko Nikula <jhnikula@gmail.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -436,6 +436,6 @@ static void __exit snd_omap_pcm_exit(void)
 }
 module_exit(snd_omap_pcm_exit);
 
-MODULE_AUTHOR("Jarkko Nikula <jhnikula@gmail.com>");
+MODULE_AUTHOR("Jarkko Nikula <jarkko.nikula@bitmer.com>");
 MODULE_DESCRIPTION("OMAP PCM DMA module");
 MODULE_LICENSE("GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2008 Nokia Corporation
  *
- * Contact: Jarkko Nikula <jhnikula@gmail.com>
+ * Contact: Jarkko Nikula <jarkko.nikula@bitmer.com>
  *          Peter Ujfalusi <peter.ujfalusi@ti.com>
  *
-- 
1.7.2.5


^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula
  2011-08-11 12:44 [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula Jarkko Nikula
@ 2011-08-11 13:09 ` Mark Brown
  2011-08-11 13:14   ` Liam Girdwood
  2011-08-12  2:48 ` Mark Brown
  1 sibling, 1 reply; 4+ messages in thread
From: Mark Brown @ 2011-08-11 13:09 UTC (permalink / raw)
  To: Jarkko Nikula; +Cc: alsa-devel, linux-kernel, Liam Girdwood

On Thu, 2011-08-11 at 15:44 +0300, Jarkko Nikula wrote:
> My gmail account got disabled and I'm not going to reopen it.
> 
> Signed-off-by: Jarkko Nikula <jarkko.nikula@bitmer.com>

Liam, I'm going to send a pull request to Takashi for 3.1 soonish -
should I just include this with that to save you having to bother?


^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula
  2011-08-11 13:09 ` Mark Brown
@ 2011-08-11 13:14   ` Liam Girdwood
  0 siblings, 0 replies; 4+ messages in thread
From: Liam Girdwood @ 2011-08-11 13:14 UTC (permalink / raw)
  To: Mark Brown
  Cc: Jarkko Nikula, alsa-devel@alsa-project.org,
	linux-kernel@vger.kernel.org

On 11/08/11 14:09, Mark Brown wrote:
> On Thu, 2011-08-11 at 15:44 +0300, Jarkko Nikula wrote:
>> My gmail account got disabled and I'm not going to reopen it.
>>
>> Signed-off-by: Jarkko Nikula <jarkko.nikula@bitmer.com>
> 
> Liam, I'm going to send a pull request to Takashi for 3.1 soonish -
> should I just include this with that to save you having to bother?
> 

Yes please. I'm waiting on an Ack from Tony for the other stuff.

Thanks

Liam

^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula
  2011-08-11 12:44 [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula Jarkko Nikula
  2011-08-11 13:09 ` Mark Brown
@ 2011-08-12  2:48 ` Mark Brown
  1 sibling, 0 replies; 4+ messages in thread
From: Mark Brown @ 2011-08-12  2:48 UTC (permalink / raw)
  To: Jarkko Nikula; +Cc: alsa-devel, linux-kernel, Liam Girdwood

On Thu, Aug 11, 2011 at 03:44:57PM +0300, Jarkko Nikula wrote:
> My gmail account got disabled and I'm not going to reopen it.
> 
> Signed-off-by: Jarkko Nikula <jarkko.nikula@bitmer.com>

Applied, thanks.

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2011-08-12  2:48 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2011-08-11 12:44 [PATCH] ASoC: omap: Update e-mail address of Jarkko Nikula Jarkko Nikula
2011-08-11 13:09 ` Mark Brown
2011-08-11 13:14   ` Liam Girdwood
2011-08-12  2:48 ` Mark Brown

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox